Index: trunk/ippTools/src/camtool.c
===================================================================
--- trunk/ippTools/src/camtool.c	(revision 13702)
+++ trunk/ippTools/src/camtool.c	(revision 13937)
@@ -184,7 +184,7 @@
     }
 
-    psString recipe = psMetadataLookupStr(&status, config->args, "-set_recipe");
-    if (!status) {
-        psError(PS_ERR_UNKNOWN, false, "failed to lookup value for -set_recipe");
+    psString reduction = psMetadataLookupStr(&status, config->args, "-set_reduction");
+    if (!status) {
+        psError(PS_ERR_UNKNOWN, false, "failed to lookup value for -set_reduction");
         return false;
     }
@@ -237,5 +237,5 @@
 
     // would could do this "all in the database" if we didn't want the option
     // of changing the label/recipe/expgroup/dvodb/etc.  So we're pulling the
     // data out so we have the option of changing these values or leaving the
     // old values in place (i.e., passing the values through).
@@ -257,5 +257,5 @@
                     workdir     ? workdir   : row->workdir,
                     label       ? label     : row->label,
-                    recipe      ? recipe    : row->recipe,
+                    reduction      ? reduction    : row->reduction,
                     expgroup    ? expgroup  : row->expgroup,
                     dvodb       ? dvodb     : row->dvodb
@@ -617,5 +617,5 @@
         pendingRow->workdir,
         pendingRow->label,
-        pendingRow->recipe,
+        pendingRow->reduction,
         pendingRow->expgroup,
         pendingRow->dvodb,
@@ -628,10 +628,10 @@
         zp_mean,
         zp_stdev,
-	fwhm,
-	fwhm_range,
-	n_stars,
-	n_extended,
-	n_cr,
-	n_astrom,
+        fwhm,
+        fwhm_range,
+        n_stars,
+        n_extended,
+        n_cr,
+        n_astrom,
         path_base,
         code
@@ -237,5 +237,5 @@
 
     // would could do this "all in the database" if we didn't want the option
-    // of changing the label/recipe/expgroup/dvodb/etc.  So we're pulling the
+    // of changing the label/reduction/expgroup/dvodb/etc.  So we're pulling the
     // data out so we have the option of changing these values or leaving the
     // old values in place (i.e., passing the values through).
